[![Aarhus Stadsarkiv](https://raw.githubusercontent.com/aarhusstadsarkiv/py-template/master/img/logo.png)](https://stadsarkiv.aarhus.dk/)
# Digital Archive [![Tests](https://github.com/aarhusstadsarkiv/digiarch/workflows/Tests/badge.svg?branch=master)](https://github.com/aarhusstadsarkiv/digiarch/actions?query=workflow%3ATests+branch%3Amaster) [![codecov](https://codecov.io/gh/aarhusstadsarkiv/digiarch/branch/master/graph/badge.svg)](https://codecov.io/gh/aarhusstadsarkiv/digiarch) [![PyPI](https://badge.fury.io/py/digiarch.svg)](https://badge.fury.io/py/digiarch)
This repository contains code pertaining to the Digital Archive Project at Aarhus Stadsarkiv.
